/*-----------------------------------------------------------------------------------------*/
//					
//								Repertoire 2002	v1.0a
//																					
// File:  Repertoire2002I.cpp	
//																											
// Contains:	Fonctions de gestions de l'interface graphiques....	
//				(listes , icones , etc...)																	
//																										
// Written by:	DEL NERO Jean Francois																					
//				GUITTON  Rmy
//																					
// Copyright: Copyright  2002-2003 ECE
//   		  www.powerofasm.fr.st
//   																											
// Change History (most recent first):																				
//     																								
//  																											
/*-----------------------------------------------------------------------------------------*/


#include <windows.h>
#include <commctrl.h>
#include <shellapi.h>
#include <stdio.h>

#include "..\resource.h"

#include "..\includes\Repertoire2002Liste.h"
#include "..\includes\Repertoire2002.h"
#include "..\includes\Repertoire2002I.h"


////////////////////////////////////////////////////////////////////////////////
//
//	Fonction permettant de changer de boite de dialogue
//
//   Entree ->	HWND dialg1 :pointeur de la boite actuelle
//				const char* dialg2 : identificateur de la nouvelle boite
//
//   Retour ->	le pointeur de la nouvelle boite
//
/////////////////////////////////////////////////////////////////////////////////

HWND ChangeDialog(HWND dialg1,const char* dialg2)
{
	HWND hDlg;
	//Chargement de la nouvelle boite
	hDlg=CreateDialog(GetModuleHandle(NULL),(const char*)dialg2,GetActiveWindow(),&DialogProc);
	
	//affichage	 de la nouvelle
	ShowWindow(hDlg,SW_SHOWNORMAL);
	// on cache l'ancienne
	ShowWindow(dialg1,SW_HIDE);

	//destruction de l'ancienne
	DestroyWindow(dialg1);
	
return hDlg;
}

////////////////////////////////////////////////////////////////////////////////
//
//	Fonction de creation du menu popup (liste)
//
//   Entree ->	HWND hwndDlg :pointeur de la boite actuelle
//				HWND hlist : identificateur de la liste eventuelle 
//				(sinon le popup sera au niveau de l'icone dans la barre des taches)
//
//   Retour ->	le pointeur de la nouvelle boite
//
/////////////////////////////////////////////////////////////////////////////////

void ListPopup(HWND hwndDlg, HWND hlist)
{
	POINT pt;
	HMENU hMenu;

	if(hlist!=NULL)
	{
		if(hlist==GetDlgItem(hwndDlg,ID_LIST_1))// Menu liste page principale
		hMenu = LoadMenu(GetModuleHandle(NULL),MAKEINTRESOURCE(ID_MENU_POPUP));

		if(hlist==GetDlgItem(hwndDlg,ID_LIST_2))// Menu liste rechercher
		hMenu = LoadMenu(GetModuleHandle(NULL),MAKEINTRESOURCE(ID_MENU_POPUP_2));
	}
	else 
	{	// Menu toolbar
		hMenu = LoadMenu(GetModuleHandle(NULL),MAKEINTRESOURCE(ID_MENU_TB));
	}

	HMENU hSubMenu = GetSubMenu(hMenu, 0);
	
	MENUITEMINFO mii;

	mii.cbSize = sizeof(MENUITEMINFO);
	mii.fMask = MIIM_STATE;
	mii.fState = MFS_GRAYED;

	GetCursorPos(&pt); // recuperation de la position de la souris

	if(hlist!=NULL)
	{
		if(ListView_GetSelectedCount(hlist)==0) 
		{	// si aucun element selectionn
			// on masque modifier et supprimer
			if(hlist==GetDlgItem(hwndDlg,ID_LIST_1))
			{
				SetMenuItemInfo(hSubMenu, ID_POPUP_SUPPRIMER_P, FALSE, &mii);
				SetMenuItemInfo(hSubMenu, ID_POPUP_MODIFIER_P, FALSE, &mii);
			}
			if(hlist==GetDlgItem(hwndDlg,ID_LIST_2))
			{
				SetMenuItemInfo(hSubMenu, ID_POPUP_SUPPRIMER_R, FALSE, &mii);
				SetMenuItemInfo(hSubMenu, ID_POPUP_MODIFIER_R, FALSE, &mii);
			}
		}
	}
	
	// affichage du popup
	TrackPopupMenu(hSubMenu, TPM_LEFTALIGN | TPM_LEFTBUTTON,pt.x, pt.y, 0, hwndDlg, NULL);
	
	DestroyMenu(hMenu);
}

////////////////////////////////////////////////////////////////////////////////
//
//	Fonction d'initialisation de l'icone ou de modification (selon mode)
//	de la barre des taches
//
//   Entree ->	HWND hwnd :pointeur de la fenetre principale
//				UINT uID : identificateur 
//				HICON hicon : icone a ajouter
//				bool Mode= true : ajout false : modification
//   Retour ->	true: ok
//				false : erreur
//
/////////////////////////////////////////////////////////////////////////////////

BOOL AjouteModifieIcone(HWND hwnd, UINT uID, HICON hicon,bool Mode)
{
	BOOL res; 
    NOTIFYICONDATA tnid; 
 
    tnid.cbSize = sizeof(NOTIFYICONDATA); //Remplissage de la structure
    tnid.hWnd = hwnd; 

    tnid.uID = uID; 
    tnid.uFlags = NIF_MESSAGE | NIF_ICON | NIF_TIP; 
    tnid.uCallbackMessage = WM_USER; 
    tnid.hIcon = hicon; 
    
	lstrcpyn(tnid.szTip,"Repertoire 2002", sizeof(tnid.szTip)); 
	if(Mode)
		res = Shell_NotifyIcon(NIM_ADD, &tnid); // Ajout
	else
		res = Shell_NotifyIcon(NIM_MODIFY, &tnid); // Modification

    if (hicon) DestroyIcon(hicon); 
 
    return res; 
}

////////////////////////////////////////////////////////////////////////////////
//
//	Fonction de suppression de l'icne de la barre des taches
//	
//   Entre ->	HWND hwnd	: pointeur de la fentre principale
//				UINT uID	: identificateur 
//	
//   Retour ->	true: ok
//				false : erreur
//
/////////////////////////////////////////////////////////////////////////////////

BOOL SupprimeIcone(HWND hwnd, UINT uID)
{
 
	BOOL res; 
	NOTIFYICONDATA tnid; 
 
	tnid.cbSize = sizeof(NOTIFYICONDATA); 
	tnid.hWnd = hwnd; 
	tnid.uID = uID; 
		 
	res = Shell_NotifyIcon(NIM_DELETE, &tnid); 
	return res; 

} 


////////////////////////////////////////////////////////////////////////////////
//
//	Fonction d'initialisation de la liste d'affichage (colonnes..)
//	
//   Entre ->	HWND hDlg :pointeur de la boite de dialogue contenant la liste
//				const char* idlist : identificateur de la liste 
//	
//   Retour ->	rien
//
/////////////////////////////////////////////////////////////////////////////////

void InitList(HWND hDlg,const char* idlist)
{
	HICON hiconItem;         
	HIMAGELIST himlSmall;   
	LV_COLUMN lvc;
	RECT rect;

	HWND hList1;
	
	//Recuperation du pointeur de la liste a partir de son id
	hList1=GetDlgItem(hDlg,(int) idlist);
	
	//Couleur de fond par defaut
	ListView_SetBkColor(hList1, GetSysColor(COLOR_WINDOW));
	
	//Recuperation de la position et de la taille dans la fenetre de la liste
	GetClientRect(hList1, &rect);

	lvc.mask = LVCF_FMT	| LVCF_TEXT | LVCF_WIDTH;
	lvc.fmt = LVCFMT_LEFT;
	
	//Initialisation des diffrentes colonnes 
	lvc.cx = rect.right * 50 / 100;
	lvc.pszText = "Nom";
	ListView_InsertColumn(hList1, 1,	&lvc);

	lvc.cx = rect.right * 42 / 100;
	lvc.pszText = "Telephone";
	ListView_InsertColumn(hList1, 2, 	&lvc);

	lvc.cx = rect.right * 30 / 100;
	lvc.pszText = "Email";
	ListView_InsertColumn(hList1, 3, 	&lvc);

	lvc.cx = rect.right * 30 / 100;
	lvc.pszText = "Adresse";
	ListView_InsertColumn(hList1, 4, 	&lvc);

	lvc.cx = rect.right * 30 / 100;
	lvc.pszText = "Date de naissance";
	ListView_InsertColumn(hList1, 5, 	&lvc);

	// initialisation de la liste d'icone...   
    himlSmall = ImageList_Create(GetSystemMetrics(SM_CXSMICON), 
						GetSystemMetrics(SM_CYSMICON), TRUE, 1, 1); 
    
	// icone normale id=0
    hiconItem = LoadIcon(GetModuleHandle(NULL), MAKEINTRESOURCE(500)); 
    ImageList_AddIcon(himlSmall, hiconItem); 
    DeleteObject(hiconItem); 
	
	// icone fete id=1
	hiconItem = LoadIcon(GetModuleHandle(NULL), MAKEINTRESOURCE(501)); 
	ImageList_AddIcon(himlSmall, hiconItem); 
	DeleteObject(hiconItem);
	
	// icone anniversaire id=2
	hiconItem = LoadIcon(GetModuleHandle(NULL), MAKEINTRESOURCE(502)); 
	ImageList_AddIcon(himlSmall, hiconItem); 
	DeleteObject(hiconItem);
        
	// Association de la liste avec les l'icones
    ListView_SetImageList(hList1, himlSmall, LVSIL_SMALL);  

}


////////////////////////////////////////////////////////////////////////////////
//
//	Fonction permettant d'ajouter un lment dans la liste d'affichage
//	
//   Entre ->	typefiche * fiche : fiche  'ajouter'
//				HWND liste : pointeur de la liste dans laquelle on veux ajouter les infos
//				int idicone: icone a associer : 0 (normale), 1 (fte) , 2 (anniversaire)
//	
//   Retour ->	rien
//
/////////////////////////////////////////////////////////////////////////////////

void AjouteFicheListe(typefiche * fiche,HWND liste,int idicone)
{
	char temp[50];
	LV_ITEM lvi;

	lvi.mask = LVIF_TEXT | LVIF_IMAGE | LVIF_PARAM | LVIF_STATE; 
    lvi.state = 0; 
    lvi.stateMask = 0; 
    lvi.pszText = LPSTR_TEXTCALLBACK;    
    lvi.iImage = idicone;                     
		
	lvi.iItem =ListView_GetItemCount(liste); 
    lvi.iSubItem = 0; 
    lvi.lParam = (LPARAM) fiche->nom;    // utile lors du trie de la liste
	
	//Creation du nouvel lment 
	ListView_InsertItem(liste, &lvi); 
	
	// Initialisation du contenu des diffrentes colonnes

	strcat(strcpy((char*)&temp,(char*)fiche->nom),ESPACENOMPRENOM);
	strcat((char*)&temp,(char*)fiche->prenom);

	ListView_SetItemText(liste, ListView_GetItemCount(liste)-1, 0, (char*)&temp);
	
	strcat(strcpy((char*)&temp,(char*)fiche->numtel),"/");
	strcat((char*)&temp,(char*)fiche->numtelp);
	if((strlen((char*)fiche->numtelp)!=0) && (strlen((char*)fiche->numtel)!=0))
	{
		ListView_SetItemText(liste, ListView_GetItemCount(liste)-1, 1, (char*)&temp);
	}
	else {
		if(strlen((char*)fiche->numtelp)!=0) 
			{
				ListView_SetItemText(liste, ListView_GetItemCount(liste)-1, 1, (char*)fiche->numtelp);
			}
		else 
		{
			if(strlen((char*)fiche->numtel)!=0) 
			{ 
				ListView_SetItemText(liste, ListView_GetItemCount(liste)-1, 1, (char*)fiche->numtel);
			}
		}
	}

	ListView_SetItemText(liste, ListView_GetItemCount(liste)-1, 2, (char*)fiche->email);

	sprintf((char*)&temp,"%s %s %s %s %s",fiche->adresse.numero,(char*)fiche->adresse.rue,(char*)fiche->adresse.codepostal,(char*)fiche->adresse.ville,(char*)fiche->adresse.pays);
	
	// traitement date
	ListView_SetItemText(liste, ListView_GetItemCount(liste)-1, 3, (char*)&temp);
	if(fiche->datedenaissance.jour!=0 && fiche->datedenaissance.mois!=0 && fiche->datedenaissance.annee!=0)
	{
		sprintf((char*)&temp,"%d/%d/%d",fiche->datedenaissance.jour,fiche->datedenaissance.mois,fiche->datedenaissance.annee);
		ListView_SetItemText(liste, ListView_GetItemCount(liste)-1, 4, (char*)&temp);
	}
}


////////////////////////////////////////////////////////////////////////////////
//
//	Fonction permettant de rafraichir la liste d'affichage
//	
//   Entre ->	laliste LaListe: la liste source
//				HWND liste : pointeur de la liste (vue)  refraichir
//	
//   Retour ->	rien
//
/////////////////////////////////////////////////////////////////////////////////


void RafraichirListe(laliste LaListe, HWND liste)
{
	laliste LaList1=LaListe;

	ListView_DeleteAllItems(liste);

	while(LaList1!=0)
	{
		AjouteFicheListe(LaList1->unefiche,liste,VerifierFete(LaList1));
		LaList1=ElemSuivant(LaList1);
	}

	ListView_SortItems(liste,ListViewCompareProc,0); 
}

